.. _glossary:

Glossary
========

.. glossary::
   :sorted:

   SKOS
    `Simple Knowledge Organization System <http://www.w3.org/2004/02/skos>`__. An
    general specification for Knowledge Organisation Systems (thesauri, word 
    lists, authority files, ...) that is commonly serialised as :term:`RDF`.

   RDF
    `Resource Description Framework <http://www.w3.org/RDF/>`__. A very flexible 
    model for data definition organised around `triples`. These triples forms a 
    directed, labeled graph, where the edges represent the named link between 
    two resources, represented by the graph nodes.

   URI
    A `Uniform Resource Identifier`.

   URN
    A URN is a specific form of a :term:`URI`.
